@@ -1,5 +1,5 @@
 package Net::Async::AMQP::ConnectionManager;
-$Net::Async::AMQP::ConnectionManager::VERSION = '0.025';
+$Net::Async::AMQP::ConnectionManager::VERSION = '0.026';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::AMQP::ConnectionManager - handle MQ connections
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
@@ -368,6 +368,11 @@ sub request_connection {
 						List::UtilsBy::extract_by {
 							Scalar::Util::refaddr($_) eq Scalar::Util::refaddr($mq)
 						} @{$self->{available_connections}};
+
+						# Also remove from the full list...
+						List::UtilsBy::extract_by {
+							Scalar::Util::refaddr($_) eq Scalar::Util::refaddr($mq)
+						} @{$self->{full_connections}};
 					}
 				);
 				my $conn = Net::Async::AMQP::ConnectionManager::Connection->new(
